pub struct PriceToEstimateFees {
pub listing_price: Box<MoneyType>,
pub shipping: Option<Box<MoneyType>>,
pub points: Option<Box<Points>>,
}Expand description
PriceToEstimateFees : Price information for an item, used to estimate fees.
Fields
listing_price: Box<MoneyType>shipping: Option<Box<MoneyType>>points: Option<Box<Points>>Implementations
sourceimpl PriceToEstimateFees
impl PriceToEstimateFees
sourcepub fn new(listing_price: MoneyType) -> PriceToEstimateFees
pub fn new(listing_price: MoneyType) -> PriceToEstimateFees
Price information for an item, used to estimate fees.